@@ -11,8 +11,8 @@ package require Direct
 package require Debug
 Debug off wsdl 10
 
-package provide WS::Wub 2.0.0
-package provide Wsdl 1.0
+package provide WS::Wub 2.4.0
+package provide Wsdl 2.4.0
 
 class create Wsdl {
     method / {r args} {
